<?php
namespace Teknisa\OPL\Controllers;

class InconsistenciaAF {
    
    const FORA_DO_LIMITE_NAO_GRAVA = array('L08', 'L09', 'L12', 'L13', 'L20');
    const INCONSISTENTE_NAO_GRAVA = array('I10', 'I11', 'I14', 'I15', 'I16', 'I17', 'I18', 'I19', 'I21');
    const MENS_INCONS = array(
            'L08'    => "Valor da AF (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '08' => "Valor da AF acima do limite",
            'L09'    => "Valor de AF(s) no mês (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '09' => "Valor das AF's no mês acima do limite",
            'I10'    => "Quantidade total da AF (VRERROR) abaixo da quantidade mínima para o fornecedor (VRLIMITE).", // '10' => "Qt. Total da AF abaixo da Qt. mínima para o fornecedor.",
            'I11'    => "Valor total da AF (VRERROR) abaixo do valor mínimo para o fornecedor (VRLIMITE).", // '11' => "Valor Total da AF abaixo do mínimo para o fornecedor.",
            'L12'    => "Valor do produto (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '12' => "Valor dos produtos da AF acima do limite do comprador.",
            'L13'    => "Valor do produto no mês (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '13' => "Valor dos produtos da AF no mês acima do limite do comprador.",
            'I14'    => "Quantidade do produto (VRERROR) abaixo do mínimo para o fornecedor(VRLIMITE).", // '14' => "Qt. do produto abaixo do mínimo para o fornecedor.",
            'I15'    => "Quantidade do produto (VRERROR) não atende ao valor de arredondamento do fornecedor (VRLIMITE).", // '15' => "Qt. do Produto não atende ao arredondamento do fornecedor",
            'I16'    => "Produto não atende às particularidades do produto.",
            'I16-1'  => "Marca Obrigatória.",
            'I16-2'  => "Marca Preferencial.",
            'I16-3'  => "Restrição a Marca.",
            'I16-4'  => "Fornecedor Obrigatório.",
            'I16-5'  => "Fornecedor Preferencial.",
            'I16-6'  => "Restrição ao Fornecedor.",
            'I16-7'  => "Marca/Fornecedor Obrigatórios.",
            'I16-8'  => "Marca/Fornecedor Preferenciais.",
            'I16-9'  => "Restrição a Marca/Fornecedor.",
            'I17'    => "Produto Preferencial.", // '17' => "Produto comprado não é o preferencial.",
            'I18'    => "Quantidade total da AF (VRERROR) abaixo da quantidade mínima para o fornecedor na região (VRLIMITE).", // '18' => "Qt. Total da AF abaixo da Qt. mínima para o fornecedor na região.",
            'I19'    => "Valor total da AF (VRERROR) abaixo do valor mínimo para o fornecedor na região (VRLIMITE).", // '19' => "Valor Total da AF abaixo do mínimo para o fornecedor na região.",
            'L20'    => "Orçamento da filial para consumo ultrapassado. Valor Orçado: VRLIMITE. Valor Realizado com a AF: VRERROR.", // '20' => "Valor do Orçamento da filial para consumo ultrapassado.",
            'I21'    => "Quantidade de cotação do produto (igual a VRERROR) abaixo da quantidade mínima de cotações exigidas (VRLIMITE).", /// '21'    => "Quantidade de cotação do produto (igual a %s)  abaixo da quantidade minima de cotações exigidas.", (nova)
            'L22'    => "Preço unitário unidade de estoque (VRERROR) acima do preço de custo objetivo (VRLIMITE).", // '22' => "Valor do item maior que o preço objetivo",
            'L23'    => "Orçamento da filial para despesa ultrapassado. Valor Orçado: VRLIMITE. Valor Realizado com a AF: VRERROR.", // '23' => "Valor do Orçamento da filial para despesa ultrapassado.",
            'L24'    => "Valor por nível do produto (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '24' => "Valor por nível dos produtos da AF acima do limite do comprador.",
            'I25'    => "Valor por nível de produto no mês (VRERROR) acima do valor máximo para o comprador (VRLIMITE).", // '25' => "Valor por nível dos produtos da AF no mês acima do limite do comprador.",
            'I26'    => "Preço unitário (unidade de estoque) maior que o ultimo preço utilizado (unidade de estoque).",
            'I28'    => "Quantidade de fornecedores com entrega no mesmo dia (VRERROR) acima do valor máximo permitido (VRLIMITE).", // '28' => "Quantidade máxima de fornecedores com entrega no mesmo dia.",
            'I29'    => "Peso para entrega no OL (VRERROR) acima do valor máximo permitido (VRLIMITE).", // '29' => "Limite máximo por entrega no OL no mesmo dia.",
            'I30'    => "Calendário de compras não foi calculado para a filial VRERROR, periodicidade VRLIMITE.", // '30' => "Calendário de compras não calculado.",
            'I31'    => "Quantidade total do produto no período (VRERROR), acima da quantidade disponível do fornecedor (VRLIMITE)", // '31' => "Quantidade disponível do fornecedor."
            'I32'    => "Data de entrega da AF não respeita o prazo do fornecedor para expedição de mercadoria de (VRLIMITE) dias.",
            'I33'    => "Obriga liberação de AF manual devido ao parâmetro \"Exigir Liberação para as AF's Manuais\".",
        );

    protected $inconsAFService;
    
    public function __construct($inconsistenciaAFService) {
        $this->inconsAFService = $inconsistenciaAFService;
    }
    
    /**
     * Metodo principal para verificar as inconsistencias da AF e de seus produtos
     * 
     * @param {string} $cdfildest Filial de destino da AF
     * @param {string} $cdfillanc Filial de lançamento da AF
     * @param {string} $nrautoforn Númeor da AF
     * @param {string} $cdfilcent Central de compras da filial de destino
     * @param {boolean} $gravaIncons Define se as inconsistencias serão gravadas
     * nas tabelas AUTOFORNE e ITEMAUTF.
     * 
     * @return {array} Caso o parametro $gravaIncons receba false, haverá um
     * retorno com as inconsistencias
     * 
    */
    public function verificaInconsistencias($cdfildest, $cdfillanc, $nrautoforn, $cdfilcent, $gravaIncons) {
        
        try {
            $inconsistencias = $this->inconsAFService->retornaInconsistencias($cdfildest, $cdfillanc, $nrautoforn, $cdfilcent);
            $autoforne = $this->inconsAFService->retornaAutoforne($cdfildest, $cdfillanc, $nrautoforn);
            $itensAF = $this->inconsAFService->retornaListaItemAutfAF($cdfildest, $cdfillanc, $nrautoforn);
            
            return self::inconsistencias($inconsistencias, $autoforne, $itensAF, $gravaIncons, $cdfildest, $cdfillanc, $nrautoforn);
            
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    
    /**
     * TODO: Verificar se o processo está sendo executado normalmente nessa nova função.
     * Testar com algo que gere inconsistências, para ver se o CDERRO vem da forma correta.
     */
    public function inconsistencias($inconsistencias, $autoforne, $itensAF, $gravaInconsistencias, $cdfildest, $cdfillanc, $nrautoforn) {
        $errosAF = '';
        $errosItemAF = '';
        $afForaLimite = 'N';
        $situacaoAF = '';
        $inconsistenciasItemAF = array();
        
        if($inconsistencias) {
            foreach($inconsistencias as $inconsistencia) {
                $afForaLimite = in_array($inconsistencia['CDERRO'], self::FORA_DO_LIMITE_NAO_GRAVA) ? 'S' : $afForaLimite;
                $situacaoAF = in_array($inconsistencia['CDERRO'], self::INCONSISTENTE_NAO_GRAVA) ? '1' : $situacaoAF;
                $msgAF = self::MENS_INCONS[$inconsistencia['CDERRO']];
                $msgAF = str_replace("VRERROR", number_format((float)$inconsistencia["VRERROR"], 2, ',', ''), $msgAF);
                $msgAF = str_replace("VRLIMITE", number_format((float)$inconsistencia["VRLIMITE"], 2, ',', ''), $msgAF);
                
                if(floatval(substr($inconsistencia['CDERRO'], 1)) < 12) {
                    if(empty($errosAF)) {
                        $errosAF = $msgAF;
                    } else {
                        $errosAF = $errosAF . "\n" . $msgAF;
                    }
                } else {
                    $inconsistencia['DSERRO'] = $msgAF;
                    array_push($inconsistenciasItemAF, $inconsistencia);
                }
                
            }
        }
        
        if ($gravaInconsistencias) {
            $this->inconsAFService->atualizaAF($cdfildest, $cdfillanc, $nrautoforn, $errosAF, $afForaLimite, $situacaoAF);
        } else {
            $this->inconsAFService->atualizaAF($cdfildest, $cdfillanc, $nrautoforn, false, false, false, false);
        }
        
        $this->inconsAFService->clearInconsItemautf($cdfildest, $cdfillanc, $nrautoforn);
        
        foreach($itensAF as $itemAF) {
            $errosItemAFRetorno = array();
            $errosItemAF = array();
            
            if($gravaInconsistencias) {
                if(((is_array($inconsistenciasItemAF) && !is_null($inconsistenciasItemAF)) ? count($inconsistenciasItemAF) : 0) > 0) {
                    foreach($inconsistenciasItemAF as $inconsistenciaItemAF) {
                        
                        if(!$inconsistenciaItemAF['CDPRODUTO'] || $inconsistenciaItemAF['CDPRODUTO'] == $itemAF->getCdproduto()) {
                            if(empty($errosItemAF)) {
                                $errosItemAF = $inconsistenciaItemAF['DSERRO'];
                            } else {
                                $errosItemAF = $errosItemAF . "\n" . $inconsistenciaItemAF['DSERRO'];
                            }
                            array_push($errosItemAFRetorno, array(
                                "CDPRODUTO" => $inconsistenciaItemAF['CDPRODUTO'],
                                "CDMARCA" => $inconsistenciaItemAF['CDMARCA'],
                                "DSERRO" => in_array($inconsistenciaItemAF['CDERRO'], self::MENS_INCONS) ? self::MENS_INCONS[$inconsistenciaItemAF['CDERRO']] : $inconsistenciaItemAF['DSERRO']));
                        }
                        
                    }
                }
            } else {
                $errosItemAF = false;
            }
            
            if (empty($errosItemAF)){
                $errosItemAF = false;    
            }
            $this->inconsAFService->atualizaItemAF($cdfildest, $cdfillanc, $nrautoforn, $itemAF->getCdmarca(), $itemAF->getCdproduto(), $errosItemAF);
        }
        
        return array(
            "AF_FORA_LIM" => $afForaLimite,
            "SITU_AF" => $situacaoAF,
            "INCONS_AF" => $errosAF,
            "INCONS_ITEM_AF" => $errosItemAFRetorno
        );
    }
    
}
   